@@ -3,7 +3,7 @@ package Database::Async::ORM::Table;
 use strict;
 use warnings;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 sub new {
     my ($class, %args) = @_;
@@ -18,5 +18,11 @@ sub tablespace { shift->{tablespace} }
 sub parents { (shift->{parents} //= [])->@* }
 sub fields { (shift->{fields} //= [])->@* }
 
+sub field_by_name {
+    my ($self, $name) = @_;
+    my ($field) = grep { $_->name eq $name } $self->fields;
+    return $field;
+}
+
 1;
 
